==> cx88-1.1.0.tar.gz: cx88-1.1.0/client/drivers/wintv_hvr4000.h <==
/*-
 * Copyright 2008 Konstantin Dimitrov <kosio.dimitrov@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __WINTV_HVR4000_H__
#define __WINTV_HVR4000_H__

#include "fmd1216me.h"
#include "cx22702.h"
#include "cx88_mpeg_driver.h"

class wintv_hvr4000
   : public cx88_mpeg_driver
{
   public:
      
      wintv_hvr4000(
         cx88_xml_config &cx88conf,
         tuner_config &tunerconf,
         const char *devnode,
         capvec &captures,
         int &error)
         : cx88_mpeg_driver(cx88conf, tunerconf, devnode, captures, error)
      {}
      
      virtual ~wintv_hvr4000(void) {}
      
   protected:
      
      virtual int create_i2c_drivers(void)
      {
         int error = 0;
         cx88_common_gpio gpio;
         gpio.in_write_mask = 0x80;
         gpio.in_read_mask = 0x0;
         gpio.inout_gpio = 0x80;
         if ((error = ioctl(m_fd, CX88_COMMON_GPIO, &gpio)) != 0)
         {
            CX88ERR << "Error issuing GPIO ioctl: " << strerror(errno) << endl;
            return error;
         }
         gpio.in_write_mask = 0x4;
         gpio.in_read_mask = 0x0;
         gpio.inout_gpio = 0x0;
         if ((error = (ioctl(m_fd, CX88_COMMON_GPIO, &gpio)) != 0))
         {
            CX88ERR << "Error issuing GPIO ioctl: " << strerror(errno) << endl;
            return error;
         }
         usleep(100000);
         m_i2c_devs[1].driver = new cx22702(m_tunerconf, *(m_i2c_devs[1].dev), DVB_INPUT_SERIAL, error);
         m_i2c_devs[0].driver = new fmd1216me(m_tunerconf, *(m_i2c_devs[0].dev));
         if ((m_i2c_devs[0].driver == NULL) || (m_i2c_devs[1].driver == NULL))
         {
            error = ENOMEM;
         }
         if (error)
         {
            CX88ERR << "Error initializing tuner/demodulator driver for WinTV HVR-4000" << endl;
            return error;
         }
         return 0;
      }
      
      virtual void destroy_i2c_drivers(void)
      {
         delete m_i2c_devs[0].driver;
         delete m_i2c_devs[1].driver;  
      }
      
      virtual int create_i2c_devices(cx88_common_i2c_config &config)
      {
         config.in_i2c_addrs[0] = 0x61;
         config.in_i2c_addrs[1] = 0x63;
         config.in_num_i2c_devices = 2;
         return 0;
      }

};

#endif

==> cx88-1.2.1.tar.gz: cx88-1.2.1/client/drivers/wintv_hvr4000.h <==
/*-
 * Copyright 2008 Konstantin Dimitrov <kosio.dimitrov@gmail.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#ifndef __WINTV_HVR4000_H__
#define __WINTV_HVR4000_H__

#include "fmd1216me.h"
#include "cx22702.h"
#include "cx88_mpeg_driver.h"

class wintv_hvr4000
   : public cx88_mpeg_driver
{
   public:
      
      wintv_hvr4000(
         cx88_xml_config &cx88conf,
         tuner_config &tunerconf,
         const char *devnode,
         capvec &captures,
         int &error)
         : cx88_mpeg_driver(cx88conf, tunerconf, devnode, captures, error)
      {}
      
      virtual ~wintv_hvr4000(void) {}
      
   protected:
      
      virtual int create_i2c_drivers(void)
      {
         int error = 0;
         cx88_common_gpio gpio;
         gpio.in_write_mask = 0x80;
         gpio.in_read_mask = 0x0;
         gpio.inout_gpio = 0x80;
         if ((error = ioctl(m_fd, CX88_COMMON_GPIO, &gpio)) != 0)
         {
            CX88ERR << "Error issuing GPIO ioctl: " << strerror(errno) << endl;
            return error;
         }
         gpio.in_write_mask = 0x4;
         gpio.in_read_mask = 0x0;
         gpio.inout_gpio = 0x0;
         if ((error = (ioctl(m_fd, CX88_COMMON_GPIO, &gpio)) != 0))
         {
            CX88ERR << "Error issuing GPIO ioctl: " << strerror(errno) << endl;
            return error;
         }
         usleep(100000);
         m_i2c_devs[1].driver = new cx22702(m_tunerconf, *(m_i2c_devs[1].dev), DVB_INPUT_SERIAL, error);
         m_i2c_devs[0].driver = new fmd1216me(m_tunerconf, *(m_i2c_devs[0].dev));
         if ((m_i2c_devs[0].driver == NULL) || (m_i2c_devs[1].driver == NULL))
         {
            error = ENOMEM;
         }
         if (error)
         {
            CX88ERR << "Error initializing tuner/demodulator driver for WinTV HVR-4000" << endl;
            return error;
         }
         return 0;
      }
      
      virtual void destroy_i2c_drivers(void)
      {
         delete m_i2c_devs[0].driver;
         delete m_i2c_devs[1].driver;  
      }
      
      virtual int create_i2c_devices(void)
      {
         m_i2c_devs[0].conf.in_addr = 0x61;
         m_i2c_devs[1].conf.in_addr = 0x63;
         return 0;
      }

};

#endif
